@@ -4,11 +4,36 @@
 # 3) we can import it into your module module
 # https://stackoverflow.com/questions/458550/standard-way-to-embed-version-into-python-package
 
-__version__ = '1.40.0'
+__version__ = '1.43.7'
 
 release_notes = {
-    '1.40.0': """
-    Support for Heatseeker game mode. No ball prediction support for it yet, so good luck!
+    '1.43.7': """
+    Bots and scripts can now specify the location of a requirements.txt file which will be analyzed
+    by the framework.
+    
+    Also:
+    - Calling begin_rendering and end_rendering on behalf of python bots so they don't need to anymore.
+    - Added wait_game_tick_packet helper to the base_script. - L0laapk3
+    - Entering 'tkinter' in a requirements.txt file will be understood.
+    - Psyonix bots can be preconfigured with a loadout. -az3
+    - Clearing car slot in game tick packet when a player leaves.
+    - Resetting gravity at the beginning of matches.
+    """,
+    '1.42.4': """
+    System for running multiple scripts that do not own cars in a match.
+    
+    Also:
+    - Set the current working directory of bots to their folder.
+    - Do less manipulation of modules when loading bots to reduce weird bugs.
+    - Small improvements to hive bot. - Will
+    """,
+    '1.41.0': """
+    Adding more flags for starting matches: enableRendering, enableStateSetting, autoSaveReplay. Also:
+    - Mac and Linux users can now use 'q' and 'r' commands to quit or reload bots. - naturecodevoid
+    - Update gravity+gamespeed variables in gametickpacket when changed by statesetting. - Kipje13
+    """,
+    '1.40.1': """
+    Support for Heatseeker game mode, including ball prediction thanks to Recruit_main and GodGamer!
     """,
     '1.39.2': """
     You can now generate a fresh loadout for your bot every match using a python script!
